pub enum Formality {
Default,
More,
Less,
PreferMore,
PreferLess,
}Expand description
Variants for formality.
Variants
Default
Default formality.
More
For a more formal language.
Less
For a more informal language.
PreferMore
For a more formal language if available, otherwise fallback to default formality.
PreferLess
For a more informal language if available, otherwise fallback to default formality.